@@ -1,7 +1,7 @@
 package Tree::Dump;
 
-our $DATE = '2016-11-21'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-11-23'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -62,7 +62,7 @@ Tree::Dump - Dump a tree object
 
 =head1 VERSION
 
-This document describes version 0.04 of Tree::Dump (from Perl distribution Tree-Dump), released on 2016-11-21.
+This document describes version 0.05 of Tree::Dump (from Perl distribution Tree-Dump), released on 2016-11-23.
 
 =head1 SYNOPSIS
 
@@ -131,11 +131,11 @@ options. Known options:
 
 =over
 
-=item * children_method => str (default: children)
+=item * get_children_method => str (default: children)
 
 Example:
 
- children_method => "get_children"
+ get_children_method => "get_children"
 
 By default, C<children> is the method that will be used on node objects to
 retrieve children nodes. But you can customize that using this option. Note that
